@@ -68,8 +68,8 @@ def reset_tree(t, method):
 
 def get_verifier_for_year(year: int):
     class _Verifier(XMLVerifier):
-        def get_cert_chain_verifier(self, ca_pem_file, ca_path):
-            verifier = super().get_cert_chain_verifier(ca_pem_file, ca_path)
+        def get_cert_chain_verifier(self, ca_pem_file):
+            verifier = super().get_cert_chain_verifier(ca_pem_file)
             verifier.verification_time = datetime(year, 1, 1)
             return verifier
 
